/**
  *  \file planetscentral/talk/topic.h
  */
#ifndef C2SERVER_PLANETSCENTRAL_TALK_TOPIC_H
#define C2SERVER_PLANETSCENTRAL_TALK_TOPIC_H

#include "planetscentral/dbclient/dbclient.h"
#include "planetscentral/dbclient/dbsubtree.h"

class Forum;

/** A discussion thread. Called "Topic" because operating systems also
    have threads. */
class Topic {
 public:
    Topic(DbClient& client, int32_t topicId);

    DbHash            header();
    DbHashStringField subject();
    DbHashIntField    forumId();
    DbHashIntField    firstPostingId();
    DbHashStringField readPermissions();
    DbHashStringField answerPermissions();
    DbHashIntField    lastPost();
    DbHashIntField    lastTime();

    DbIntSet          messages();
    DbStringSet       watchers();

    Forum             forum();

    void              remove();
    void              removeEmpty();

    bool              isSticky();
    void              setSticky(bool enable);

    int32_t           getId() const;

    static int32_t allocateTopic(DbClient& client);

    bool              exists();
    IntValue*         describe();

 private:
    DbSubtree topic;
    int32_t topicId;
};

#endif
